@@ -45,7 +45,7 @@ pub struct Command {
     pub selected: bool,
     pub dir: Option<String>,
     pub features: Features,
-    pub match_bounds: Vec<(usize, usize)>,
+    pub match_indices: Vec<usize>,
 }
 
 #[derive(Debug, Clone, Serialize)]
@@ -254,15 +254,22 @@ impl History {
         fuzzy: i16,
         result_sort: &ResultSort,
     ) -> Vec<Command> {
-        let mut like_query = "%".to_string();
+        let (wildcard, match_function, cmd) = if Self::is_case_sensitive(cmd) {
+            // escape '*' with '[*]' and replace '%' with '*' for glob matching
+            ("*", "GLOB", cmd.replace("*", "[*]").replace("%", "*"))
+        } else {
+            ("%", "LIKE", cmd.to_string())
+        };
+
+        let mut like_query = wildcard.to_string();
 
         if fuzzy > 0 {
-            like_query.push_str(&cmd.split("").collect::<Vec<&str>>().join("%"));
+            like_query.push_str(&cmd.split("").collect::<Vec<&str>>().join(wildcard));
         } else {
-            like_query.push_str(cmd);
+            like_query.push_str(&cmd);
         }
 
-        like_query.push('%');
+        like_query += wildcard;
 
         let order_by_column: &str = match &result_sort {
             ResultSort::LastRun => "last_run",
@@ -270,14 +277,16 @@ impl History {
         };
 
         let query: &str = &format!(
-            "{} {} {} {}",
+            "{} {} {} {} {}",
             "SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir, rank,
                 age_factor, length_factor, exit_factor, recent_failure_factor,
                 selected_dir_factor, dir_factor, overlap_factor, immediate_overlap_factor,
                 selected_occurrences_factor, occurrences_factor, last_run
             FROM contextual_commands
-            WHERE cmd LIKE (:like)",
-            "ORDER BY",
+            WHERE cmd",
+            match_function,
+            "(:like)
+            ORDER BY",
             order_by_column,
             "DESC LIMIT :limit"
         )[..];
@@ -294,36 +303,7 @@ impl History {
                         .get(1)
                         .unwrap_or_else(|err| panic!("McFly error: cmd to be readable ({err})"));
 
-                    let lowercase_text = text.to_lowercase();
-                    let lowercase_cmd = cmd.to_lowercase();
-
-                    let bounds = match fuzzy {
-                        0 => lowercase_text
-                            .match_indices(&lowercase_cmd)
-                            .map(|(index, _)| (index, index + cmd.len()))
-                            .collect::<Vec<_>>(),
-                        _ => {
-                            let mut search_iter = lowercase_cmd.chars().peekable();
-                            let mut matches = lowercase_text
-                                .match_indices(|c| {
-                                    let next = search_iter.peek();
-
-                                    if next.is_some() && next.unwrap() == &c {
-                                        let _advance = search_iter.next();
-
-                                        return true;
-                                    }
-
-                                    false
-                                })
-                                .map(|m| m.0);
-
-                            let start = matches.next().unwrap_or(0);
-                            let end = matches.last().unwrap_or(start) + 1;
-
-                            vec![(start, end)]
-                        }
-                    };
+                    let bounds = Self::calc_match_indices(&text, &cmd, fuzzy);
 
                     Ok(Command {
                         id: row.get(0).unwrap_or_else(|err| {
@@ -351,7 +331,7 @@ impl History {
                         rank: row.get(8).unwrap_or_else(|err| {
                             panic!("McFly error: rank to be readable ({err})")
                         }),
-                        match_bounds: bounds,
+                        match_indices: bounds,
                         features: Features {
                             age_factor: row.get(9).unwrap_or_else(|err| {
                                 panic!("McFly error: age_factor to be readable ({err})")
@@ -429,10 +409,11 @@ impl History {
                     // the likelihood of the weight flipping the outcome for
                     // the originally lower-ranked result.
 
-                    let a_start = a.match_bounds[0].0;
-                    let b_start = b.match_bounds[0].0;
-                    let a_len = a.match_bounds[0].1 - a_start;
-                    let b_len = b.match_bounds[0].1 - b_start;
+                    let a_start = *a.match_indices.first().unwrap_or(&0);
+                    let b_start = *b.match_indices.first().unwrap_or(&0);
+
+                    let a_len = a.match_indices.last().map(|i| i + 1).unwrap_or(0) - a_start;
+                    let b_len = b.match_indices.last().map(|i| i + 1).unwrap_or(0) - b_start;
 
                     let a_mod =
                         1.0 - (a_start + a_len) as f64 / (a_start + b_start + a_len + b_len) as f64;
@@ -451,6 +432,44 @@ impl History {
         names
     }
 
+    /// Enable case sensitivity when input string contains uppercase
+    fn is_case_sensitive(cmd: &str) -> bool {
+        cmd.chars().any(|c| c.is_uppercase())
+    }
+
+    /// Calculate the indices of the matches in the text.
+    fn calc_match_indices(text: &str, cmd: &str, fuzzy: i16) -> Vec<usize> {
+        let (text, cmd) = if Self::is_case_sensitive(cmd) {
+            (text.to_string(), cmd.to_string())
+        } else {
+            (text.to_lowercase(), cmd.to_lowercase())
+        };
+
+        match fuzzy {
+            0 => text
+                .match_indices(&cmd)
+                .flat_map(|(index, _)| index..index + cmd.len())
+                .collect(),
+            _ => {
+                let mut search_iter = cmd.chars().peekable();
+
+                text.match_indices(|c| {
+                    let next = search_iter.peek();
+
+                    if next.is_some() && next.unwrap() == &c {
+                        let _advance = search_iter.next();
+
+                        return true;
+                    }
+
+                    false
+                })
+                .map(|m| m.0)
+                .collect()
+            }
+        }
+    }
+
     #[allow(clippy::too_many_arguments)]
     pub fn build_cache_table(
         &self,
@@ -632,9 +651,13 @@ impl History {
     ) -> Vec<Command> {
         let order = if random { "RANDOM()" } else { "id" };
         let query = if session_id.is_none() {
-            format!("SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir FROM commands ORDER BY {order} DESC LIMIT :limit OFFSET :offset")
+            format!(
+                "SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir FROM commands ORDER BY {order} DESC LIMIT :limit OFFSET :offset"
+            )
         } else {
-            format!("SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir FROM commands WHERE session_id = :session_id ORDER BY {order} DESC LIMIT :limit OFFSET :offset")
+            format!(
+                "SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir FROM commands WHERE session_id = :session_id ORDER BY {order} DESC LIMIT :limit OFFSET :offset"
+            )
         };
 
         let closure: fn(&Row) -> rusqlite::Result<Command> = |row| {
@@ -859,20 +882,21 @@ impl History {
             for command in commands {
                 if !IGNORED_COMMANDS.contains(&command.command.as_str()) {
                     let simplified_command = SimplifiedCommand::new(&command.command, true);
-                    if !command.command.is_empty() && !simplified_command.result.is_empty() {
-                        if let Err(e) = statement.execute(named_params! {
+                    if !command.command.is_empty()
+                        && !simplified_command.result.is_empty()
+                        && let Err(e) = statement.execute(named_params! {
                             ":cmd": &command.command,
                             ":cmd_tpl": &simplified_command.result.clone(),
                             ":session_id": &"IMPORTED",
                             ":when_run": &command.when,
                             ":exit_code": &0,
                             ":selected": &0,
-                        }) {
-                            println!(
-                                "A single history line could not be saved due to '{}' (command was '{}'), but other inserts should be fine.",
-                                e, &command.command
-                            );
-                        }
+                        })
+                    {
+                        println!(
+                            "A single history line could not be saved due to '{}' (command was '{}'), but other inserts should be fine.",
+                            e, &command.command
+                        );
                     }
                 }
             }
