@@ -23,19 +23,19 @@ impl Init {
     }
     pub fn init_bash() {
         let script = include_str!("../mcfly.bash");
-        print!("{}", script);
+        print!("{script}");
     }
     pub fn init_zsh() {
         let script = include_str!("../mcfly.zsh");
-        print!("{}", script);
+        print!("{script}");
     }
     pub fn init_fish() {
         let script = include_str!("../mcfly.fish");
-        print!("{}", script);
+        print!("{script}");
     }
     pub fn init_pwsh() {
         let script = include_str!("../mcfly.ps1")
             .replace("::MCFLY::", env::current_exe().unwrap().to_str().unwrap());
-        print!("{}", script);
+        print!("{script}");
     }
 }
