@@ -8,13 +8,13 @@ use crate::settings::{InterfaceView, KeyScheme, ResultFilter};
 use crate::settings::{ResultSort, Settings};
 use chrono::{Duration, TimeZone, Utc};
 use crossterm::event::KeyCode::Char;
-use crossterm::event::{read, Event, KeyCode, KeyEvent, KeyEventKind, KeyModifiers};
+use crossterm::event::{Event, KeyCode, KeyEvent, KeyEventKind, KeyModifiers, read};
 use crossterm::style::{Color, Print, SetBackgroundColor, SetForegroundColor};
 use crossterm::terminal::{self, LeaveAlternateScreen};
 use crossterm::terminal::{Clear, ClearType, EnterAlternateScreen};
 use crossterm::{cursor, execute, queue};
 use humantime::format_duration;
-use std::io::{stdout, Write};
+use std::io::{Write, stdout};
 use std::string::String;
 
 pub struct Interface<'a> {
@@ -67,7 +67,7 @@ impl MenuMode {
                 }
             },
             MenuMode::ConfirmDelete => {
-                return String::from("Delete selected command from the history? (Y/N)")
+                return String::from("Delete selected command from the history? (Y/N)");
             }
         }
 
@@ -272,12 +272,7 @@ impl<'a> Interface<'a> {
                 SetBackgroundColor(bg),
                 SetForegroundColor(fg),
                 Print(Interface::truncate_for_display(
-                    command,
-                    &self.input.command,
-                    width,
-                    highlight,
-                    fg,
-                    self.debug
+                    command, width, highlight, fg, self.debug
                 ))
             )
             .unwrap();
@@ -402,10 +397,8 @@ impl<'a> Interface<'a> {
     }
 
     fn confirm(&mut self, confirmation: bool) {
-        if confirmation {
-            if let MenuMode::ConfirmDelete = self.menu_mode {
-                self.delete_selection();
-            }
+        if confirmation && let MenuMode::ConfirmDelete = self.menu_mode {
+            self.delete_selection();
         }
         self.menu_mode = MenuMode::Normal;
     }
@@ -991,13 +984,11 @@ impl<'a> Interface<'a> {
 
     fn truncate_for_display(
         command: &Command,
-        search: &str,
         width: u16,
         highlight_color: Color,
         base_color: Color,
         debug: bool,
     ) -> String {
-        let mut prev: usize = 0;
         let debug_space = if debug { 90 } else { 0 };
         let max_grapheme_length = if width > debug_space {
             width - debug_space - 9
@@ -1006,23 +997,22 @@ impl<'a> Interface<'a> {
         };
         let mut out = FixedLengthGraphemeString::empty(max_grapheme_length);
 
-        if !search.is_empty() {
-            for (start, end) in &command.match_bounds {
-                if prev != *start {
-                    out.push_grapheme_str(&command.cmd[prev..*start]);
+        let mut match_indices = command.match_indices.iter().peekable();
+
+        for (i, c) in command.cmd.char_indices() {
+            match match_indices.peek() {
+                Some(&&j) if i == j => {
+                    let _ = match_indices.next();
+                    execute!(out, SetForegroundColor(highlight_color)).unwrap();
+                    out.push_grapheme_str(c);
+                }
+                _ => {
+                    execute!(out, SetForegroundColor(base_color)).unwrap();
+                    out.push_grapheme_str(c);
                 }
-
-                execute!(out, SetForegroundColor(highlight_color)).unwrap();
-                out.push_grapheme_str(&command.cmd[*start..*end]);
-                execute!(out, SetForegroundColor(base_color)).unwrap();
-                prev = *end;
             }
         }
 
-        if prev != command.cmd.len() {
-            out.push_grapheme_str(&command.cmd[prev..]);
-        }
-
         if debug {
             out.max_grapheme_length += debug_space;
             out.push_grapheme_str("  ");
