@@ -203,7 +203,7 @@ impl Default for Settings {
                     results_bg: Color::Black,
                     results_hl: Color::Blue,
                     results_selection_fg: Color::Black,
-                    results_selection_bg: Color::White,
+                    results_selection_bg: Color::DarkGrey,
                     results_selection_hl: Color::DarkGreen,
                 },
                 lightmode_colors: LightModeColors {
@@ -369,10 +369,10 @@ impl Settings {
 
                 settings.dir = directory.unwrap_or_else(pwd);
 
-                if let Ok(results) = env::var("MCFLY_RESULTS") {
-                    if let Ok(results) = u16::from_str(&results) {
-                        settings.results = results;
-                    }
+                if let Ok(results) = env::var("MCFLY_RESULTS")
+                    && let Ok(results) = u16::from_str(&results)
+                {
+                    settings.results = results;
                 }
 
                 if let Some(results) = results {
@@ -486,10 +486,10 @@ impl Settings {
             _ => KeyScheme::Emacs,
         };
 
-        if let Ok(prompt) = env::var("MCFLY_PROMPT") {
-            if prompt.chars().count() == 1 {
-                settings.prompt = prompt;
-            }
+        if let Ok(prompt) = env::var("MCFLY_PROMPT")
+            && prompt.chars().count() == 1
+        {
+            settings.prompt = prompt;
         }
 
         settings
