@@ -67,13 +67,12 @@ impl TrainingSampleGenerator {
             let results = history.find_matches("", -1, 0, &crate::settings::ResultSort::Rank);
 
             // Get the features for this command at the time it was logged.
-            if positive_examples <= negative_examples {
-                if let Some(our_command_index) = results.iter().position(|c| c.cmd.eq(&command.cmd))
-                {
-                    let what_should_have_been_first = &results[our_command_index];
-                    data_set.push((what_should_have_been_first.features.clone(), true));
-                    positive_examples += 1;
-                }
+            if positive_examples <= negative_examples
+                && let Some(our_command_index) = results.iter().position(|c| c.cmd.eq(&command.cmd))
+            {
+                let what_should_have_been_first = &results[our_command_index];
+                data_set.push((what_should_have_been_first.features.clone(), true));
+                positive_examples += 1;
             }
 
             if negative_examples <= positive_examples {
